import {VueRenderer} from '@tiptap/vue-3'
import tippy from 'tippy.js'

import vars from './var.vue'

export default {
	items: () => {
		return ['']
	},

	render: () => {
		let component
		let popup

		return {
			onStart: props => {
				component = new VueRenderer(vars, {
					props,
					editor: props.editor,
				})

				if (!props.clientRect) {
					return
				}

				popup = tippy('body', {
					getReferenceClientRect: props.clientRect,
					appendTo: () => document.body,
					content: component.element,
					showOnCreate: true,
					interactive: true,
					trigger: 'manual',
					placement: 'bottom-start',
				})
			},

			onUpdate(props) {
				component.updateProps(props)

				if (!props.clientRect) {
					return
				}

				popup[0].setProps({
					getReferenceClientRect: props.clientRect,
				})
			},

			onKeyDown(props) {
				if (props.event.key === 'Escape') {
					popup[0].hide()
					return true
				}
				// 将查询字符透传给组件
				return component.ref?.onKeyDown?.(props)
			},

			onExit() {
				popup[0]?.destroy?.()
				component?.destroy?.()
			},
		}
	},
}