import axios from 'axios'
import { BizError } from '@/types/core';
import {getToken, useUserStore} from '@/service/user-store'
import {message} from 'ant-design-vue'

const axiosService = axios.create({
    baseURL: '/api/v2',
    timeout: 5000,

})

function processUnauthorized (){
    const store = useUserStore();
    store.logout().then(async ()=>{
        message.error('获取登录凭证失败,请重新登录')
    })
    // const err = new BizError('获取登录凭证失败,请重新登录', 401, e.response?.data);
    // router.replace(`/login?redirect=${router.currentRoute.value.path}`).then(() => {
    //     console.log('401 show login')
    // })
}
export function request<T>(options: RequestOption) {
    return new Promise<T>((resolve, reject) => {
        const { url, method, data, baseURL, getOriginResult } = options;

        axiosService.request<APIResponse<T>>({
            url,
            method: method || 'get',
            data,
            baseURL,
            headers: {
                'Authorization': getToken()
            }
        }).then(res => {
            if (res.status != 200) {
                reject(new BizError("Service Internal Exception,Please Try Later!", res.status))
                return;
            }
            if (getOriginResult) {
                resolve(res.data as unknown as T)
                return;
            }
            // const
            const { code, message, data } = res.data
            if (code == 0) {
                resolve(data as unknown as T)
            } else if(code == 401){
                // reject(new BizError('获取登录凭证失败,请重新登录', code, data))
                processUnauthorized();
            } else {
                reject(new BizError(message, code, data))
            }
        }).catch(e => {
            if(e.status == 401){
                if(e.response){
                    try{
                        if(e.response?.data.code == 401){
                            processUnauthorized()
                        }
                        return;
                    }catch (e){}
                }
            }
            reject(new BizError(e.message, 500))
        })
    })
}
export function post<T>(url:string,data?: any){
    return request<T>({
        url,
        method:'post',
        data
    })
}
export function get<T>(url:string){
    return request<T>({url})
}