import {getList} from "@/service/api/product.ts";
import {ref} from "vue";

type InputValue = {
	name: string;
	key: string;
	unit?: string;
	placeholder?: string;
	type?: string;
	addition?: {
		key: string
		placeholder: string
		unit?: string;
	}
}

/*
{
  "weight": 50,
  "niaosu": 12,
  "ruineng": 10,
  "ruidai": 0,
  "ruixian": 0,
  "ruigao": 0,
  "ruisu": 0,
  "nengquanli": 0,
  "kangquanli": 0,
  "kangquangan": 0,
  "baipuli": 0,
  "ailunduo": 0,
  "weiwo": 0,
  "jiaweiti": 0,
  "yilijia": 0,
  "ruiyixi": 0,
  "nengquansu": 0,
  "ansu": 0,
  "quanansu": 0,
  "yilijia100": 0,
  "shui": 0,
  "anjisuan_ruye": 0,
  "yilijia100_ruye": 0,
  "quanansu_ruye": 0,
  "ansu_ruye": 0,
  "nengquansu_ruye": 0,
  "ruqingdanbailiang": 0,
  "ruianji": 0,
  "quanyingda": 0,
  "likawen": 0,
  "lefanming85": 0,
  "lefanming114": 0,
  "anjisuan": 0,
  "litai": 0,
  "lineng": 0,
  "liwen": 0,
  "youwen": 0,
  "yingtuolipite20": 0,
  "yingtuolipite30": 0,
  "putaotangluhuana5": 0,
  "putaotang5": 0,
  "putaotang10": 0,
  "putaotang50": 0,
  "luhuana09": 0,
  "luhuana10": 0,
  "geliefusi": 0,
  "luhuajia": 0,
  "baidanbai": 0
}
 */
const inputList: InputValue[] = [
	{name: '体重', key: 'weight',},
	{name: '24h尿素', key: 'niaosu',},
	// 肠内制剂
	{name: '瑞能', key: 'ruineng', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '瑞代', key: 'ruidai', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '瑞先', key: 'ruixian', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '瑞高', key: 'ruigao', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '瑞素', key: 'ruisu', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '能全力', key: 'nengquanli', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '康全力', key: 'kangquanli', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '康全甘', key: 'kangquangan', placeholder: '入液量', unit: 'ml', type: 'gut'}, // 新增
	{name: '百普力', key: 'baipuli', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '爱伦多', key: 'ailunduo', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '维沃', key: 'weiwo', placeholder: '入液量', unit: 'ml', type: 'gut'},
	// 新增 230409
	{name: '佳维体', key: 'jiaweiti', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '伊力佳', key: 'yilijia', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '瑞易西', key: 'ruiyixi', placeholder: '入液量', unit: 'ml', type: 'gut'},

	{
		name: '能全素',
		key: 'nengquansu',
		placeholder: '入量（勺）',
		unit: 'ml',
		type: 'gut',
		addition: {key: 'nengquansu_ruye', placeholder: '入液量'}
	},
	{
		name: '安素',
		key: 'ansu',
		placeholder: '入量（勺）',
		unit: '勺',
		type: 'gut',
		addition: {key: 'ansu_ruye', placeholder: '入液量'}
	},
	{
		name: '全安素',
		key: 'quanansu',
		placeholder: '入量（勺）',
		unit: '勺',
		type: 'gut',
		addition: {key: 'quanansu_ruye', placeholder: '入液量'}
	},
	// 新增 230409
	{
		name: '益力佳',
		key: 'yilijia100',
		placeholder: '入量（勺）',
		unit: 'ml',
		type: 'gut',
		addition: {key: 'yilijia100_ruye', placeholder: '入液量'}
	},
	// o water
	{
		name: '乳清蛋白量(g)',
		key: 'ruqingdanbailiang',
		placeholder: '入量',
		unit: 'g',
		type: 'gut',
		addition: {key: 'ruqingdanbailiang_ruye', placeholder: '入液量'}
	},

	// { name: '雀巢Beneprotein', key: 'quecaoBeneprotein', placeholder: '入量',unit:'g',type: 'gut' },
	{name: '瑞安吉', key: 'ruianji', placeholder: '入液量', unit: 'ml', type: 'gut'},

	// 静脉制剂
	// { name: '卡文1440ml', key: 'kawen1440', placeholder: '入液量', unit:'ml', type: 'vein' },
	// { name: '卡文1920ml', key: 'kawen1920', placeholder: '入液量', unit:'ml', type: 'vein' },
	// 新增 230409
	{name: '水', key: 'shui', placeholder: '入液量', unit: 'ml', type: 'gut'},
	{name: '全营达', key: 'quanyingda', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '力卡文', key: 'likawen', placeholder: '入液量', unit: 'ml', type: 'vein'},


	{name: '乐凡命8.5%', key: 'lefanming85', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '乐凡命11.4%', key: 'lefanming114', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{
		name: '其他氨基酸',
		key: 'anjisuan',
		placeholder: '入液量',
		unit: 'ml',
		type: 'vein',
		addition: {key: 'anjisuan_ruye', placeholder: '', unit: '%',}
	},
	{name: '力太', key: 'litai', placeholder: '入液量', unit: 'ml', type: 'vein'},

	{name: '力能', key: 'lineng', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '力文', key: 'liwen', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '尤文', key: 'youwen', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '英脱利匹特20%', key: 'yingtuolipite20', placeholder: '入液量', unit: 'ml', type: 'vein'},// 新增
	{name: '英脱利匹特30%', key: 'yingtuolipite30', placeholder: '入液量', unit: 'ml', type: 'vein'},// 新增
	{name: '5%葡萄糖氯化钠', key: 'putaotangluhuana5', placeholder: '入液量', unit: 'ml', type: 'vein'},// 新增
	{name: '5%葡萄糖', key: 'putaotang5', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '10%葡萄糖', key: 'putaotang10', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '50%葡萄糖', key: 'putaotang50', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '0.9%氯化钠', key: 'luhuana09', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '10%氯化钠', key: 'luhuana10', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '格列福斯', key: 'geliefusi', placeholder: '入液量', unit: 'ml', type: 'vein'},
	{name: '氯化钾', key: 'luhuajia', placeholder: '入液量', unit: 'ml', type: 'vein'},
	// { name: '其他液体', key: 'qitayeti', placeholder: '入液量', unit:'ml', type: 'vein' }, // 新增
	{name: '白蛋白', key: 'baidanbai', placeholder: '入液量', unit: 'ml', type: 'vein'}, // 新增
]

export function getInputValue() {
	const list: ResultVarItem[] = [];
	inputList.forEach(item => {

		if (item.addition) {
			const additionExt = item.addition.placeholder || item.addition.unit
			list.push({
				label: `${item.name}${additionExt ? '-' + additionExt : ''}`,
				text: `${item.name}${additionExt ? '-' + additionExt : ''}`,
				value: `input.${item.addition.key}`,
			})
		}
		const ext = item.placeholder || item.unit
		list.push({
			text: `${ext?`${ext}(${item.name})`:item.name}`,
			label: `${ext?`ruye(${item.name})`:item.name}`,
			value: `input.${item.key}`,
		})
	})
	return list
}

const ValueKeys = [
	'power',
	'protein',
	'glu',
	'fat',
	'cellulose',
	'na',
	'k',
	'ca',
	'p',
	'mg',
]

export function getAllProduct() {
	const list = ref<{
		[key: string]: ProductInfoModel
	}>({})
	getList({
		page: 1,
		limit: 10000
	}).then(res => {
		const data: {
			[key: string]: ProductInfoModel
		} = {}
		res.list.forEach(it => {
			data[it.alias] = it;
		})
		list.value = data
	});
	return list
}

export function getProductValue() {
	const list = ref<ResultVarItem[]>(getInputValue())

	getList({
		page: 1,
		limit: 10000
	}).then(res => {
		const _list: ResultVarItem[] = [];
		res.list.forEach(it => {
			ValueKeys.forEach(key => {
				const label = `${it.name}-${key}`
				_list.push({
					label,
					value: `${it.alias}.${key}`,
					text: label,
				})
				// _list.push({
				// 	label: `${it.name}.${key}`,
				// 	value: `${it.alias}.${key}`,
				// 	text: label,
				// })
			})
		})
		list.value = [
			...list.value,
			..._list,
		];
	})
	return list;
}