import { defineStore } from "pinia"
import { onMounted, ref } from "vue"
import { md5 } from "js-md5";
import { sleep } from "@/core/sleep.ts";
import { userLogin, getInfo,saveUser,updateUserPassword } from "./api/user";

import { BizError } from "@/types/core.ts";

type LoginParam = {
    account: string;
    password: string;
}

const LOGIN_SESSION_KEY = 'x-yy-js-data-user';
export function getToken() {
    return localStorage.getItem('x-yy-js-data-user')
}

export const useUserStore = defineStore('counter', () => {
    const userInfo = ref<UserInfo>()
    const userInit = ref(false)

    // 登录
    const login = async (data: LoginParam) => {
        await sleep(500);
        const info = await userLogin({
            ...data,
            password: md5(data.password),
        });
        userInfo.value = info.user;
        localStorage.setItem(LOGIN_SESSION_KEY, info.token)
    }

    // 登出
    const logout = async () => {
        localStorage.removeItem(LOGIN_SESSION_KEY)
        userInfo.value = undefined;
    }
    // 更新用户信息
    const updateUserInfo = async (info: Partial<UserInfo>) => {
        await saveUser(info)
        await getUserInfo()
    }
    const updatePassword = async (data: ModifyUserPassword) => {
        if(!userInfo.value) throw new BizError('please login',401)
        data.id = userInfo.value.id; 
        await updateUserPassword(data)
    }
    // 获取用户信息
    const getUserInfo = async () => {
        const token = localStorage.getItem(LOGIN_SESSION_KEY);
        if (!token) {
            throw new BizError('need token', 401)
        }
        userInfo.value = await getInfo();
    }
    onMounted(() => {

        getUserInfo().catch((e: BizError) => {
            if (e.code == 401) {
                //router.replace(`/login?redirect=${router.currentRoute.value.path}`).then(() => )
                console.log('401 show login')
            }
        }).finally(() => {
            setTimeout(() => {
                userInit.value = true
            }, 500)
        })
    })

    return {
        userInfo,
        userInit,
        login,
        logout,
        updateUserInfo,
        getUserInfo,
        updatePassword
    }
})
